@@ -22,9 +22,6 @@ class TabPreprocess(QtWidgets.QWidget):
             pwidget = WidgetPreprocessItem(identifier=pid, parent=self)
             self._map_widgets_to_preproc_ids[pwidget] = pid
             self.layout_preproc_area.addWidget(pwidget)
-            if pid == "correct_tip_offset":
-                idx = pwidget.comboBox.findData("deviation_from_baseline")
-                pwidget.comboBox.setCurrentIndex(idx)
             pwidget.preproc_step_changed.connect(self.on_preproc_step_changed)
         spacer_item = QtWidgets.QSpacerItem(20, 0,
                                             QtWidgets.QSizePolicy.Minimum,
@@ -33,6 +30,7 @@ class TabPreprocess(QtWidgets.QWidget):
 
         # Add recommended item (see `self.preproc_set_preset`)
         self.cb_preproc_presel.addItem("Recommended")
+        self.on_preset_changed()
         self.cb_preproc_presel.activated.connect(self.on_preset_changed)
         self.cb_preproc_presel.currentIndexChanged.connect(
             self.on_preset_changed)
@@ -78,15 +76,26 @@ class TabPreprocess(QtWidgets.QWidget):
                 req_stps = preproc.get_steps_required(pid)
                 if req_stps:
                     for pwid in self._map_widgets_to_preproc_ids:
-                        if self._map_widgets_to_preproc_ids[pwid] in req_stps:
+                        if (self._map_widgets_to_preproc_ids[pwid] in req_stps
+                                and not pwid.isChecked()):
+                            # Prevent every pwid from sending out signals!
+                            # Instead call `check_selection` every time.
+                            pwid.blockSignals(True)
                             pwid.setChecked(True)
+                            pwid.blockSignals(False)
+                            self.check_selection()
             else:
                 # Disable all steps that depend on this one
                 for dwid in self._map_widgets_to_preproc_ids:
                     did = self._map_widgets_to_preproc_ids[dwid]
                     req_stps = preproc.get_steps_required(did)
-                    if req_stps and pid in req_stps:
+                    if req_stps and pid in req_stps and dwid.isChecked():
+                        # Prevent every dwid from sending out signals!
+                        # Instead call `check_selection` every time.
+                        dwid.blockSignals(True)
                         dwid.setChecked(False)
+                        dwid.blockSignals(False)
+                        self.check_selection()
 
     def current_preprocessing(self):
         # Note: Preprocessing is cached once in `fdist`.
@@ -111,11 +120,15 @@ class TabPreprocess(QtWidgets.QWidget):
         text = self.cb_preproc_presel.currentText()
         if text == "None":
             used_methods = []
+            method_options = {}
         elif text == "Recommended":
             used_methods = ["compute_tip_position",
                             "correct_force_offset",
                             "correct_tip_offset",
                             "correct_split_approach_retract"]
+            method_options = {
+                "correct_tip_offset": "deviation_from_baseline",
+            }
         else:
             raise ValueError(f"Unknown text '{text}'!")
 
@@ -123,6 +136,16 @@ class TabPreprocess(QtWidgets.QWidget):
             pwidget.blockSignals(True)
             pid = self._map_widgets_to_preproc_ids[pwidget]
             pwidget.setChecked(pid in used_methods)
+            if pid in method_options:
+                value = method_options[pid]
+                if isinstance(value, str):
+                    idx = pwidget.comboBox.findData(value)
+                    pwidget.comboBox.setCurrentIndex(idx)
+                elif pwidget.comboBox.isVisible():
+                    # be future-proof
+                    pwidget.comboBox.setCurrentIndex(0)
+                else:
+                    raise NotImplementedError("TODO")
             pwidget.blockSignals(False)
         self.apply_preprocessing()
 
